#!/bin/bash
# test_release.sh

# run the python main files
python test/test_wyckedsceptre.py
python examples/encounter_example.py
python examples/example.py

# check all Python files for pep8 compatability
pep8 --repeat --ignore=errors --verbose *.py
pep8 --repeat --ignore=errors --verbose wyckedsceptre/*.py
pep8 --repeat --ignore=errors --verbose test/*.py

# check PyChecker
pychecker *.py
pychecker wyckedsceptre/*.py
pychecker test/*.py

# check Pylint
pylint *.py
pylint wyckedsceptre/*.py
pylint test/*.py

python -3 test/test_wyckedsceptre.py
python -3 examples/encounter_example.py
python -3 examples/example.py

